@@ -73,8 +73,8 @@ SLOT_STATUS_INVALID          = 5
 
 INVALID_DEVICE_INDEX      =0xFF
 #IMG_PATH                  ='/home/pi/gxf/python/spotii/img/'
-IMG_PATH                  ='img/'
-
+#IMG_PATH                  ='img/'
+IMG_PATH = '/home/pi/app/spotii/img'
 
 MAX_CAMERA_RESOLUTION_WIDTH     =1600
 MAX_CAMERA_RESOLUTION_HEIGHT    =1200
